SciPy
=====

:Release: |release|
:Date: |today|

SciPy (pronounced "Sigh Pie") is open-source software for mathematics,
science, and engineering.

.. toctree::
   :maxdepth: 2

   tutorial/index

.. toctree::
   :maxdepth: 1

   hacking
   api
   release

Reference
---------

.. toctree::
   :maxdepth: 1

   cluster
   constants
   fftpack
   integrate
   interpolate
   io
   linalg
   misc
   ndimage
   odr
   optimize
   signal
   sparse
   sparse.linalg
   sparse.csgraph
   spatial
   special
   stats
   stats.mstats
   weave
